@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010 Aurimas Cernius
+ * Copyright (C) 2010-2011 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 #include <boost/format.hpp>
 
 #include <glibmm/i18n.h>
+#include <glibmm/miscutils.h>
 #include <gtkmm/image.h>
 #include <gtkmm/printoperation.h>
 #include <gtkmm/stock.h>
@@ -82,7 +83,7 @@ namespace printnotes {
     m_item->signal_activate().connect(
       sigc::mem_fun(*this, &PrintNotesNoteAddin::print_button_clicked));
     m_item->add_accelerator ("activate", get_window()->get_accel_group(),
-                             GDK_P, Gdk::CONTROL_MASK,
+                             GDK_KEY_P, Gdk::CONTROL_MASK,
                              Gtk::ACCEL_VISIBLE);
     m_item->show ();
     add_plugin_menu_item (m_item);
@@ -240,7 +241,7 @@ namespace printnotes {
     Glib::RefPtr<Pango::Layout> layout = context->create_pango_layout();
 
     layout->set_font_description(
-      get_window()->editor()->get_style()->get_font());
+      get_window()->editor()->get_pango_context()->get_font_description());
     int start_index = p_start.get_line_index();
     indentation = 0;
 
@@ -288,7 +289,7 @@ namespace printnotes {
                                 int page_number, int total_pages)
   {
     Glib::RefPtr<Pango::Layout> layout = context->create_pango_layout();
-    Pango::FontDescription font_desc = get_window()->editor()->get_style()->get_font();
+    Pango::FontDescription font_desc = get_window()->editor()->get_pango_context()->get_font_description();
     font_desc.set_style(Pango::STYLE_NORMAL);
     font_desc.set_weight(Pango::WEIGHT_LIGHT);
     layout->set_font_description(font_desc);
@@ -310,7 +311,7 @@ namespace printnotes {
     std::string timestamp = sharp::DateTime::now().to_string ("%c");
 
     Glib::RefPtr<Pango::Layout> layout = context->create_pango_layout ();
-    Pango::FontDescription font_desc = get_window()->editor()->get_style()->get_font();
+    Pango::FontDescription font_desc = get_window()->editor()->get_pango_context()->get_font_description();
     font_desc.set_style(Pango::STYLE_NORMAL);
     font_desc.set_weight(Pango::WEIGHT_LIGHT);
     layout->set_font_description(font_desc);
