@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2011 Aurimas Cernius
+ * Copyright (C) 2010-2012 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -77,8 +77,9 @@ namespace gnote {
       Gnote::obj().open_search_all();
     }
 
-    static void gnote_app_startup(GApplication *)
+    static void gnote_app_startup(GApplication * application)
     {
+      G_APPLICATION_CLASS(gnote_app_parent_class)->startup(application);
       Gnote::obj().startup();
     }
 
@@ -381,7 +382,11 @@ namespace gnote {
     if(m_is_panel_applet) {
       return;
     }
+#ifdef HAVE_GLIB_2_32
+    g_application_quit(G_APPLICATION(m_app));
+#else
     Gtk::Main::quit();
+#endif
   }
 
   void Gnote::on_preferences_response(int /*res*/)
@@ -437,7 +442,7 @@ namespace gnote {
     about.set_program_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(utils::get_icon("gnote", 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2010-2011 Aurimas Cernius\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2010-2012 Aurimas Cernius\n"
                           "Copyright \xc2\xa9 2009-2011 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
@@ -638,7 +643,7 @@ namespace gnote {
       else {
         execute(remote);
       }
-      Gtk::Main::quit();
+      Gnote::obj().on_quit_gnote_action();
     }
     return 0;
   }
